@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# $Id: wlink.py 1400 2016-01-21 19:15:04Z mwall $
+# $Id: wlink.py 1776 2017-12-03 12:08:16Z mwall $
 # Copyright 2014 Matthew Wall
 """weewx driver for WeatherLink web sites
    download data from a weatherlink site for use in weewx
@@ -50,7 +50,7 @@ import weewx
 import weewx.drivers
 
 DRIVER_NAME = "WeatherLink"
-DRIVER_VERSION = "0.9"
+DRIVER_VERSION = "0.12"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -90,6 +90,8 @@ class WeatherLink(weewx.drivers.AbstractDevice):
     For archive data, make a request to the server.
     """
 
+    rain_bucket_dict = {0:'0.01 inches', 1:'0.2 mm', 2:'0.1 mm'}
+
     def __init__(self, **stn_dict):
         loginf("version is %s" % DRIVER_VERSION)
         self.username = stn_dict['username']
@@ -97,6 +99,10 @@ class WeatherLink(weewx.drivers.AbstractDevice):
         self.format = stn_dict.get('format', 'B')
         loginf("expecting HTML format '%s'" % self.format)
         self.poll_interval = float(stn_dict.get('poll_interval', 60))
+        loginf("polling interval is %s" % self.poll_interval)
+        rain_bucket_type = int(stn_dict.get('rain_bucket_type', 0))
+        loginf("rain bucket type is %d (%s)" %
+               (rain_bucket_type, self.rain_bucket_dict[rain_bucket_type]))
         self.max_tries = int(stn_dict.get('max_tries', 5))
         self.retry_wait = int(stn_dict.get('retry_wait', 30))
         self.raw_data_cache = stn_dict.get('raw_data_cache', None)
@@ -104,7 +110,13 @@ class WeatherLink(weewx.drivers.AbstractDevice):
         if self._archive_interval is not None:
             self._archive_interval = int(self._archive_interval)
             loginf("archive interval is %s seconds" % self._archive_interval)
-        loginf("polling interval is %s" % self.poll_interval)
+
+        if rain_bucket_type == 1:
+            _archive_map['rain'] = _archive_map['rainRate'] = _bucket_1
+        elif rain_bucket_type == 2:
+            _archive_map['rain'] = _archive_map['rainRate'] = _bucket_2
+        else:
+            _archive_map['rain'] = _archive_map['rainRate'] = _val100
 
     @property
     def hardware_name(self):
@@ -181,12 +193,14 @@ class WeatherLink(weewx.drivers.AbstractDevice):
         data = self.get_data("http://weatherlink.com/webdl.php"
                              "?timestamp=0&user=%s&pass=%s&action=headers" %
                              (self.username, self.password))
-        if data is not None:
-            for line in data.splitlines():
-                if line.find('ArchiveInt=') >= 0:
-                    logdbg('found archive interval: %s' % line)
-                    return int(line[11:])
-        return None
+        if data is None:
+            raise weewx.WeeWxIOError("download of archive interval failed")
+        for line in data.splitlines():
+            if line.find('ArchiveInt=') >= 0:
+                logdbg('found archive interval: %s' % line)
+                return int(line[11:])
+        raise weewx.WeeWxIOError("cannot determine archive interval from %s" %
+                                 data)
 
     # adapted from the implementation in the vantage driver
     def unpack_archive_packet(self, raw_record_string):
