@@ -1,4 +1,4 @@
-# $Id: install.py 1399 2016-01-21 19:13:01Z mwall $
+# $Id: install.py 1775 2017-12-02 20:13:50Z mwall $
 # installer for WeatherLink driver
 # Copyright 2014 Matthew Wall
 
@@ -10,17 +10,10 @@ def loader():
 class WeatherLinkInstaller(ExtensionInstaller):
     def __init__(self):
         super(WeatherLinkInstaller, self).__init__(
-            version="0.9",
+            version="0.12",
             name='wlink',
             description='driver that collects data from weatherlink.com',
             author="Matthew Wall",
             author_email="mwall@users.sourceforge.net",
-            config={
-                'Station', {
-                    'station_type': 'WeatherLink'},
-                'OWFS', {
-                    'driver': 'user.wlink',
-                    'username': 'USERNAME',
-                    'password': 'PASSWORD'}},
             files=[('bin/user', ['bin/user/wlink.py'])]
             )
